# tests/hrecipe
> The contents of this folder are strongly based on David Megginson work around
  the "JSON processing specs for HXL data". The drafted YAML usage is mostly
  an [Syntactic sugar](https://en.wikipedia.org/wiki/Syntactic_sugar).

Quick links:
- "JSON processing specs for HXL data, David Megginson, 2021-03-11"
  - https://docs.google.com/presentation/d/17vXOnq2atIDnrODGLs36P1EaUvT-vXPjsc2I1q1Qc50/edit#slide=id.p
    - JSON specs:
      - https://github.com/HXLStandard/hxl-proxy/wiki/JSON-processing-specs
    - Filter parameters:
      - https://github.com/HXLStandard/hxl-proxy/wiki/JSON-recipes
    - API endpoint:
      - https://github.com/HXLStandard/hxl-proxy/wiki/Process-JSON-spec
- Test online
  - https://proxy.hxlstandard.org/api/from-spec.html
